/*
 * Copyright 2005, 2006 University of Leiden.
 *
 * This file is part of MIA+EWS.
 *
 * MIA+EWS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * MIA+EWS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with MIA; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: parser.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $ */
/*******************************************************************************
* E.S.O. - VLT project
*
* "@(#) $Id: parser.h,v 1.4 2002/05/08 21:24:48 jdejong Exp $"
*
* who       when      what
* --------  --------  ----------------------------------------------
* jdejong 2002-05-08  imported
*/

/************************************************************************
 *
 *----------------------------------------------------------------------
 */

/* header file for input parser */
#ifndef PARSER_H
#define PARSER_H
#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <string.h>
#include <memory.h>

/* parser structures */
#define MAX_LIST_ITEMS 1000

/* parser data types, currently only Float (double), Integer (long) 
 and Strings */
enum parser_type {PFLOAT=0, PINTEGER, PSTRING}; 
typedef long   Integer; 
typedef double Float; 

/* structure for parser entry */
typedef struct
{
  char            *name;      /* name of item  */
  enum parser_type type;      /* item type     */
  Integer          ivalue;    /* Integer default/read value */
  Float            fvalue;    /* Float default/read value  */
  char            *cvalue;    /* String default/read value  */
} parse_item;

/* structure for parser list */
typedef struct
{
  Integer  NumItem;                  /* number of items in list */
  parse_item* list[MAX_LIST_ITEMS];  /* list */
} parse_list;

/* external interface */
parse_list* create_parse_list();
/*--------------------------------------------------------------------*/
/*  Create parser list                                                */
/*   Returns:  Empty parser_list                                      */
/*--------------------------------------------------------------------*/

void kill_parse_list(parse_list* list);
/*--------------------------------------------------------------------*/
/*  Delete parser list                                                */
/*   Inputs:                                                          */
/*     list  Parse_list structure to delete                           */
/*--------------------------------------------------------------------*/

parse_item* make_parse_item (char *name,
			     enum parser_type type,
			     Float fvalue,
			     Integer ivalue,
			     char *cvalue);
/*--------------------------------------------------------------------*/
/*  Create a parse_item from values                                   */
/*   Inputs:                                                          */
/*     name     name of item                                          */
/*     type     item type                                             */
/*     fvalue   Float default value                                   */
/*     ivalue   Integer default value                                 */
/*     cvalue   String default value                                  */
/*   Returns:  parse_item pointer to new structure with values filled */
/*--------------------------------------------------------------------*/

int parse_input_file(char *name,
		     parse_list *list);
/*--------------------------------------------------------------------*/
/*  Parse values from input file into list.                           */
/*   Inputs:                                                          */
/*      name    name of input file                                    */
/*      list    parse list structure                                  */
/*   Returns:    0 on success, else failure                           */
/*--------------------------------------------------------------------*/

int find_parse_entry(char *name, parse_list* list);
/*--------------------------------------------------------------------*/
/* Find a given entry in a parse list, return index if OK, else -1    */
/*   Inputs:                                                          */
/*      name    name of parse_item                                    */
/*      list    parse list structure                                  */
/*   Returns:   index if OK, else -1                                  */
/*--------------------------------------------------------------------*/

#endif  /* PARSER_H */
/* */
